package com.ruoyi.web.controller.info;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StudentMindOld;
import com.ruoyi.system.service.IStudentMindOldService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学生心理健康历史信息Controller
 * 
 * @author ruoyi
 * @date 2023-08-03
 */
@RestController
@RequestMapping("/mind/old")
public class StudentMindOldController extends BaseController
{
    @Autowired
    private IStudentMindOldService studentMindOldService;

    /**
     * 查询学生心理健康历史信息列表
     */
    @PreAuthorize("@ss.hasPermi('mind:old:list')")
    @GetMapping("/list")
    public TableDataInfo list(StudentMindOld studentMindOld)
    {
        List<StudentMindOld> list = studentMindOldService.selectStudentMindOldList(studentMindOld);
        return getDataTable(list);
    }

    /**
     * 导出学生心理健康历史信息列表
     */
    @PreAuthorize("@ss.hasPermi('mind:old:export')")
    @Log(title = "学生心理健康历史信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StudentMindOld studentMindOld)
    {
        List<StudentMindOld> list = studentMindOldService.selectStudentMindOldList(studentMindOld);
        ExcelUtil<StudentMindOld> util = new ExcelUtil<StudentMindOld>(StudentMindOld.class);
        util.exportExcel(response, list, "学生心理健康历史信息数据");
    }

    /**
     * 获取学生心理健康历史信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mind:old:query')")
    @GetMapping(value = "/{mindId}")
    public AjaxResult getInfo(@PathVariable("mindId") Long mindId)
    {
        return success(studentMindOldService.selectStudentMindOldByMindId(mindId));
    }

    /**
     * 新增学生心理健康历史信息
     */
    @PreAuthorize("@ss.hasPermi('mind:old:add')")
    @Log(title = "学生心理健康历史信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StudentMindOld studentMindOld)
    {
        return toAjax(studentMindOldService.insertStudentMindOld(studentMindOld));
    }

    /**
     * 修改学生心理健康历史信息
     */
    @PreAuthorize("@ss.hasPermi('mind:old:edit')")
    @Log(title = "学生心理健康历史信息", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody StudentMindOld studentMindOld)
    {
        return toAjax(studentMindOldService.updateStudentMindOld(studentMindOld));
    }

    /**
     * 删除学生心理健康历史信息
     */
    @PreAuthorize("@ss.hasPermi('mind:old:remove')")
    @Log(title = "学生心理健康历史信息", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{mindIds}")
    public AjaxResult remove(@PathVariable Long[] mindIds)
    {
        return toAjax(studentMindOldService.deleteStudentMindOldByMindIds(mindIds));
    }
}
